@@ -3,13 +3,13 @@ package DateTime::Format::Strptime;
 use strict;
 use warnings;
 
-our $VERSION = '1.71';
+our $VERSION = '1.73';
 
 use Carp qw( carp croak );
 use DateTime 1.00;
-use DateTime::Locale 0.45;
+use DateTime::Locale 1.05;
 use DateTime::Format::Strptime::Types;
-use DateTime::TimeZone 0.79;
+use DateTime::TimeZone 2.09;
 use Params::ValidationCompiler qw( validation_for );
 use Try::Tiny;
 
@@ -61,17 +61,6 @@ use constant PERL_58 => $] < 5.010;
         my $class = shift;
         my %args  = $validator->(@_);
 
-        if ( $args{locale} && !ref $args{locale} ) {
-            $args{locale} = DateTime::Locale->load( $args{locale} )
-                or croak "Could not create locale from $args{locale}";
-        }
-
-        if ( $args{time_zone} && !ref $args{time_zone} ) {
-            $args{time_zone}
-                = DateTime::TimeZone->new( name => $args{time_zone} )
-                or croak "Could not create time zone from $args{time_zone}";
-        }
-
         my $self = bless {
             %args,
             zone_map => $class->_build_zone_map( $args{zone_map} ),
@@ -982,13 +971,18 @@ sub parse_duration {
     croak q{DateTime::Format::Strptime doesn't do durations.};
 }
 
-sub format_datetime {
-    my $self = shift;
-    my $dt   = shift;
+{
+    my $validator = validation_for( params => [ { type => t('DateTime') } ] );
+
+    sub format_datetime {
+        my $self = shift;
+        my ($dt) = $validator->(@_);
+
+        my $pattern = $self->pattern;
+        $pattern =~ s/%O/$dt->time_zone->name/eg;
+        return $dt->clone->set_locale( $self->locale )->strftime($pattern);
+    }
 
-    my $pattern = $self->pattern;
-    $pattern =~ s/%O/$dt->time_zone->name/eg;
-    return $dt->clone->set_locale( $self->locale )->strftime($pattern);
 }
 
 sub format_duration {
@@ -1053,7 +1047,7 @@ DateTime::Format::Strptime - Parse and format strp and strf time patterns
 
 =head1 VERSION
 
-version 1.71
+version 1.73
 
 =head1 SYNOPSIS
 
@@ -1453,7 +1447,7 @@ Rick Measham <rickm@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Christian Hansen D. Ilmari Mannsåker key-amb
+=for stopwords Christian Hansen D. Ilmari Mannsåker key-amb Mohammad S Anwar
 
 =over 4
 
@@ -1469,6 +1463,10 @@ D. Ilmari Mannsåker <ilmari.mannsaker@net-a-porter.com>
 
 key-amb <yasutake.kiyoshi@gmail.com>
 
+=item *
+
+Mohammad S Anwar <mohammad.anwar@yahoo.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
