@@ -3,13 +3,15 @@ package DateTime::Format::Strptime::Types;
 use strict;
 use warnings;
 
-our $VERSION = '1.71';
+our $VERSION = '1.73';
 
 use parent 'Specio::Exporter';
 
+use DateTime;
 use DateTime::Locale::Base;
+use DateTime::Locale::FromData;
 use DateTime::TimeZone;
-use Specio 0.18;
+use Specio 0.33;
 use Specio::Declare;
 use Specio::Library::Builtins -reexport;
 use Specio::Library::String -reexport;
@@ -29,6 +31,7 @@ coerce(
 );
 
 object_isa_type( 'TimeZone', class => 'DateTime::TimeZone' );
+object_isa_type('DateTime');
 
 coerce(
     t('TimeZone'),
@@ -60,7 +63,7 @@ DateTime::Format::Strptime::Types - Types used for parameter checking in DateTim
 
 =head1 VERSION
 
-version 1.71
+version 1.73
 
 =head1 DESCRIPTION
 
